Struct ExtImageCopyCaptureSessionV1
pub struct ExtImageCopyCaptureSessionV1 { /* private fields */ }wayland and Linux only.Expand description
image copy capture session
This object represents an active image copy capture session.
After a capture session is created, buffer constraint events will be emitted from the compositor to tell the client which buffer types and formats are supported for reading from the session. The compositor may re-send buffer constraint events whenever they change.
To advertise buffer constraints, the compositor must send in no particular order: zero or more shm_format and dmabuf_format events, zero or one dmabuf_device event, and exactly one buffer_size event. Then the compositor must send a done event.
When the client has received all the buffer constraints, it can create a buffer accordingly, attach it to the capture session using the attach_buffer request, set the buffer damage using the damage_buffer request and then send the capture request.
See also the Request enum for this interface.
Implementations
impl ExtImageCopyCaptureSessionV1
impl ExtImageCopyCaptureSessionV1
pub fn buffer_size(&self, width: u32, height: u32)
pub fn buffer_size(&self, width: u32, height: u32)
image capture source dimensions
Provides the dimensions of the source image in buffer pixel coordinates.
The client must attach buffers that match this size.
pub fn shm_format(&self, format: Format)
pub fn shm_format(&self, format: Format)
shm buffer format
Provides the format that must be used for shared-memory buffers.
This event may be emitted multiple times, in which case the client may choose any given format.
pub fn dmabuf_device(&self, device: Vec<u8>)
pub fn dmabuf_device(&self, device: Vec<u8>)
dma-buf device
This event advertises the device buffers must be allocated on for dma-buf buffers.
In general the device is a DRM node. The DRM node type (primary vs. render) is unspecified. Clients must not rely on the compositor sending a particular node type. Clients cannot check two devices for equality by comparing the dev_t value.
pub fn dmabuf_format(&self, format: u32, modifiers: Vec<u8>)
pub fn dmabuf_format(&self, format: u32, modifiers: Vec<u8>)
dma-buf format
Provides the format that must be used for dma-buf buffers.
The client may choose any of the modifiers advertised in the array of 64-bit unsigned integers.
This event may be emitted multiple times, in which case the client may choose any given format.
pub fn done(&self)
pub fn done(&self)
all constraints have been sent
This event is sent once when all buffer constraint events have been sent.
The compositor must always end a batch of buffer constraint events with this event, regardless of whether it sends the initial constraints or an update.
pub fn stopped(&self)
pub fn stopped(&self)
session is no longer available
This event indicates that the capture session has stopped and is no longer available. This can happen in a number of cases, e.g. when the underlying source is destroyed, if the user decides to end the image capture, or if an unrecoverable runtime error has occurred.
The client should destroy the session after receiving this event.